#define MyAppName "My Second Application"
#define MyAppVerName "My Second Application 1.0"
#define MyAppPublisher "My Company, Inc."
#define MyAppURL "http://www.mycompany.com"
#define MyAppExeName "sample1.exe"

[Setup]
AppName={#MyAppName}
AppVerName={#MyAppVerName}
AppPublisher={#MyAppPublisher}
AppPublisherURL={#MyAppURL}
AppSupportURL={#MyAppURL}
AppUpdatesURL={#MyAppURL}
DefaultDirName={pf}\{#MyAppName}
DefaultGroupName={#MyAppName}
LicenseFile=license.txt
OutputBaseFilename=setup
Compression=lzma
SolidCompression=yes

[Types]
Name: "complete";    Description: "Full installation"
Name: "workstation"; Description: "Workstation only"
Name: "database";    Description: "Database installation"
Name: "custom";      Description: "Custom installation";  Flags: iscustom

[Components]
Name: "appfiles"; Description: "Program files";  Types: complete
Name: "required"; Description: "Required files"; Types: complete workstation custom; Flags: fixed
Name: "database"; Description: "Database files"; Types: complete database

[Tasks]
Name: desktopicon; Description: {cm:CreateDesktopIcon}; GroupDescription: {cm:AdditionalIcons}; Flags: unchecked

[Files]
Source: sample1.exe;        DestDir: {app};             Components: appfiles; Flags: ignoreversion
Source: readme.txt;         DestDir: {app};             Components: appfiles; Flags: ignoreversion
Source: data\customers.dbf; DestDir: {code:GetDataDir}; Components: database; Flags: onlyifdoesntexist
Source: data\customers.cdx; DestDir: {code:GetDataDir}; Components: database; Flags: onlyifdoesntexist

[Registry]
Root: HKLM; Subkey: Software\{#MyAppPublisher}\{#MyAppName}\Settings; ValueType: string; ValueName: AppDir;  ValueData: {code:GetAppDir};  Components: required
Root: HKLM; Subkey: Software\{#MyAppPublisher}\{#MyAppName}\Settings; ValueType: string; ValueName: DataDir; ValueData: {code:GetDataDir}; Components: database

[Icons]
Name: {group}\{#MyAppName};       Filename: {app}\{#MyAppExeName}
Name: {commondesktop}\{#MyAppName}; Filename: {app}\{#MyAppExeName}; Tasks: desktopicon

[Run]
Filename: {app}\{#MyAppExeName}; Description: {cm:LaunchProgram,{#MyAppName}}; Flags: nowait postinstall skipifsilent; OnlyBelowVersion: 0,6

[Code]
var
   DataDirPage: TInputDirWizardPage;

procedure InitializeWizard;
begin
	{ Create the data directory page }
	DataDirPage := CreateInputDirPage( wpSelectComponents,
		'Select Data Directory', 'Where should the data files be installed?',
		'Setup will install the database files into the following folder.',
		False, 'New Folder');
	DataDirPage.Add( 'To continue, click Next. If you would like to select a different location, click Browse');
end;

procedure RegisterPreviousData( PreviousDataKey: Integer);
begin
   { Save the DataDir setting so we can restore it next time }
   SetPreviousData( PreviousDataKey, 'DataDir', DataDirPage.Values[0]);
end;

function ShouldSkipPage( PageID: Integer): Boolean;
begin
   { Skip the DataDir page if the database component is not selected }
   if ( PageID = DataDirPage.ID) then
      Result := pos( 'database', WizardSelectedComponents( false)) = 0
end;

function NextButtonClick( CurPageID: Integer): Boolean;
begin
   { If we're leaving the wpSelectDir page we now have the value for the 'app' variable,
     which we can use to create the default value for the DataDir variable if there is no
     value already available from a previous install. }
   if ( CurPageID = wpSelectDir) then
      begin
         { Set the value of the data directory to the value of DataDir from the previous
           install, if any. }
         DataDirPage.Values[0] := GetPreviousData( 'DataDir', '');
         { If there was no previous value then supply a default value. }
         if DataDirPage.Values[0] = '' then
            DataDirPage.Values[0] := ExpandConstant( '{app}') + '\Data';
      end;
   Result := True;
end;

function UpdateReadyMemo( Space, NewLine, MemoUserInfoInfo, MemoDirInfo, MemoTypeInfo,
   MemoComponentsInfo, MemoGroupInfo, MemoTasksInfo: String): String;
var
   S: String;
begin
   { Fill the 'Ready Memo' with the normal settings and the custom settings }
   S := MemoComponentsInfo + NewLine + NewLine;

   { Workstation component is selected }
   if pos( 'workstation', WizardSelectedComponents( false)) > 0 then
      S := S + MemoDirInfo + ' (workstation)' + NewLine;

   { Database component is selected }
   if pos( 'database', WizardSelectedComponents( false)) > 0 then
      if pos( 'workstation', WizardSelectedComponents( false)) > 0 then
         { Workstation component is also selected }
         S := S + Space + DataDirPage.Values[0] + ' (database)' + NewLine
      else begin
         { Workstation component is not selected }
         S := S + 'Destination Directory:' + NewLine;
         S := S + Space + DataDirPage.Values[0] + ' (database)' + NewLine;
      end;

   Result := S;
end;

function GetDataDir( S: String): String;
begin
   { Return the selected DataDir }
   Result := DataDirPage.Values[0];
end;

function GetAppDir( Default: String): String;
begin
   { Return the install dir }
   Result := ExpandConstant( '{app}');
end;

